#
# spec file for package pagemon
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2017-2020, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pagemon
Version:        0.02.01
Release:        1.9
Summary:        Interactive memory/page monitoring tool
License:        GPL-2.0-or-later
Group:          System/Monitoring
URL:            https://github.com/ColinIanKing/pagemon
Source:         https://github.com/ColinIanKing/pagemon/archive/refs/tags/V%{version}.tar.gz
BuildRequires:  ncurses-devel

%description
pagemon is a ncurses based interactive memory/page monitoring tool
allowing one to browse the memory map of an active running process
on Linux.

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Benchmark
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (pagemon and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash completion script for %{name}.

%prep
%setup -q

%build
export CFLAGS="%{optflags}"
%make_build

%install
%make_install

%files
%license COPYING
%doc README.md
%{_sbindir}/pagemon
%{_mandir}/man8/pagemon.8%{?ext_man}

%files bash-completion
%{_datadir}/bash-completion/completions/%{name}

%changelog
* Sun Feb 19 2023 Dirk Müller <dmueller@suse.com>
- update to 0.02.01:
  * Makefile: bump version
  * debian/changelog: fix incorrect month in previous date
  * debian/control: update standards version to 4.6.2
  * debian/control: use libncurses-dev instead of libncurses5-dev
  * Update copyright
* Wed Jan  4 2023 Dirk Müller <dmueller@suse.com>
- Update to 0.02.00:
  * Remove redundant increment of y
  * Remove redundant assignment to attr
  * Remove unused assignment to ptr
* Wed Apr 20 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 0.01.23
  * Improve documentation
- Update URL to current github project site (old site is orphaned)
* Thu Apr 29 2021 Martin Hauke <mardnh@gmx.de>
- update to version 0.01.22
  * Remove redundant reset of addr to 0
  * Avoid potential division by zero of window_pages
* Sat Nov  7 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.01.21
  * Zero ws struct to clear static analysis warnings
* Mon Aug 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.01.20:
  * initialize memory before usage
* Sun Mar  8 2020 Martin Hauke <mardnh@gmx.de>
- Supplement against bash-completion, not bash
* Sun Mar  8 2020 Martin Hauke <mardnh@gmx.de>
- Drop SLE12 compat ifdef
* Wed Feb 26 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.01.19
  * Add bash completion script
* Tue Dec 17 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.01.18
  * Fix indexing out-of-range error on g.mem_info.pages when idx
    is out of range
* Wed Sep 25 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.01.17
  * Fix indexing out-of-range error on g.mem_info.pages when idx
    is out of range
* Tue Jul 30 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.01.16
  * Format pagemap_info by casting to uint64_t
* Sun Jul  7 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.01.15
  * Fix spelling mistake
  * Update copyright year
  * Add project page to README
  * Voidify some function returns and minor code clean up
* Mon Jul  9 2018 mardnh@gmx.de
- Update to version 0.01.14
  * Makefile: remove .xz tarball on make clean rule
  * debian/watch: change watch file to check for .xz
  * Makefile: use xz compression for tarball
  * Add .travis.yml to make dist rule
  * Makefile: bump version
  * Add kpage count stats
  * Rename idx to avoid name shadowing with global function index
  * Add travis yaml file
* Sun Jun 17 2018 mardnh@gmx.de
- Update to version 0.01.13
  * Makefile: bump version
  * Add some more constifications
  * voidify function returns
  * debian/copyright: use secure URI
  * debian/control: update debhelper to >= 11
  * debian/compat: update to 11
  * debian/control: remove trailing empty line
* Thu Jan 11 2018 mardnh@gmx.de
- Update to version 0.01.12
  * Makefile: bump version
  * Makefile: Add -fPIC
  * Fix build failure on ia64 when perf is not available
  * Update copyright year
* Thu Dec 28 2017 mardnh@gmx.de
- Update to version 0.01.11
  * Bump version
  * Update Standards-Version to 4.1.2
  * Print physical location rather than pfn
* Wed May 10 2017 mardnh@gmx.de
- update to version 0.01.10
  * Makefile: bump version
  * fix shadowing offset variable
  * fix shadowing map variable
  * Makefile: Add PEDANTIC gcc flags
- update to version 0.01.09
  * Makefile: bump version
  * Debian/control: update Standards-Version to 3.9.8
  * Remove redundant statement, found using scan-build
* Thu Feb 18 2016 mardnh@gmx.de
- initial package
